Informix — SQLAlchemy 0.7 Documentation

# SQLAlchemy 0.7 Documentation

Search:
Release: 0.7.4 | Release Date: December 9, 2011

# Informix

Support for the Informix database.

This dialect is mostly functional as of SQLAlchemy 0.6.5.

## informixdb Notes

Support for the informixdb DBAPI.

informixdb is available at:

> http://informixdb.sourceforge.net/

### Connecting

Sample informix connection:

    engine = create_engine('informix+informixdb://user:password@host/dbname')